==> aestimo-1.2.1.tar.gz: aestimo-1.2.1/AUTHORS.md <==
# AUTHORs and CONTRIBUTIONS for AESTIMO

Contributors of Aestimo. Names are listed in alphabetic order. Name, Initials, Email, Institution and Country are given, respectively.

## Version 1.2.1

### Committers

* Robert Steed, RS, robsteed0-AT-gmail.com

## Version 1.2 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria
* Robert Steed, RS, robsteed0-AT-gmail.com
 
## Version 1.1 

### Committers 

*	Robert Steed, RS, robsteed0-AT-gmail.com
  
## Version 1.0 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria
*	Robert Steed, RS, robsteed0-AT-gmail.com
  
## Version 0.9 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria
*	Robert Steed, RS, robsteed0-AT-gmail.com

## Version 0.8 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria
*	Robert Steed, RS, robsteed0-AT-gmail.com
*	Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.

### Contributors 

*	Beyza Sarikavak-Lisesivdin - Thanks for new material parameters.
*	Zbigniew Koziol - Thanks for the code help about logging and custom output directory option.

## Version 0.7 

### Committers 

*	Robert Steed, RS, robsteed0-AT-gmail.com
*	Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.

## Version 0.1 - 0.6 

### Committers 

*	Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.

==> aestimo-2.0.2.tar.gz: aestimo-2.0.2/AUTHORS.md <==
# AUTHORs and CONTRIBUTIONS for AESTIMO

Contributors of Aestimo. Names are listed in alphabetic order. Name, Initials, Email, Institution and Country are given, respectively.

## Version 2.0

### Committers

* Hamza Hebal, HH, h.hebal-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria.
* Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.

## Version 1.2.1

### Committers

* Robert Steed, RS, robsteed0-AT-gmail.com

## Version 1.2 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria.
* Robert Steed, RS, robsteed0-AT-gmail.com

## Version 1.1 

### Committers 

*	Robert Steed, RS, robsteed0-AT-gmail.com

## Version 1.0 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria.
*	Robert Steed, RS, robsteed0-AT-gmail.com

## Version 0.9 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria.
*	Robert Steed, RS, robsteed0-AT-gmail.com

## Version 0.8 

### Committers 

*	Hamza Hebal, HH, ncmagra54-AT-yahoo.fr, University of Djilali Lyabes Sidi Bel Abes, Algeria.
*	Robert Steed, RS, robsteed0-AT-gmail.com
*	Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.

### Contributors 

*	Beyza Sarikavak-Lisesivdin - Thanks for new material parameters.
*	Zbigniew Koziol - Thanks for the code help about logging and custom output directory option.

## Version 0.7 

### Committers 

*	Robert Steed, RS, robsteed0-AT-gmail.com
*	Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.

## Version 0.1 - 0.6 

### Committers 

*	Sefer Bora Lisesivdin, SBL, sblisesivdin-AT-gmail.com, Gazi University, Turkey.
